/*
  Copyright (c) 2013 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
  Copyright (c) 2013 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "core/byte_select_api.h"
  #include "core/chardef_api.h"

const unsigned char gt_byte_select[] = {
  /* select first bit */
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,
  (GtUchar) 0, (GtUchar) 0, (GtUchar) 0, (GtUchar) 0,

  /* select second bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,
  (GtUchar) 1, (GtUchar) 1, (GtUchar) 1, (GtUchar) 1,

  /* select third bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,
  (GtUchar) 2, (GtUchar) 2, (GtUchar) 2, (GtUchar) 2,

  /* select fourth bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,
  (GtUchar) 3, (GtUchar) 3, (GtUchar) 3, (GtUchar) 3,

  /* select fifth bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6, (GtUchar) 5, (GtUchar) 5,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,
  (GtUchar) 4, (GtUchar) 4, (GtUchar) 4, (GtUchar) 4,

  /* select sixth bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 6, (GtUchar) 6, (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,
  (GtUchar) 5, (GtUchar) 5, (GtUchar) 5, (GtUchar) 5,

  /* select seventh bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7,
  (GtUchar) 8, (GtUchar) 7, (GtUchar) 6, (GtUchar) 6,

  /* select eigth bit */
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 8,
  (GtUchar) 8, (GtUchar) 8, (GtUchar) 8, (GtUchar) 7
};
